@@ -306,11 +306,11 @@ print(LD4)
 
 cleanProg(.longData3d.scale,,,2) # meanNA sdNA
 scale(LD1)
-restaureRealData(LD1)
+restoreRealData(LD1)
 scale(LD1,center=c(2,3))
-restaureRealData(LD1)
+restoreRealData(LD1)
 scale(LD1,center=c(2,3),scale=c(1,1))
-restaureRealData(LD1)
+restoreRealData(LD1)
 scale(LD1,scale=c(1,1))
 scale(LD1n)
 scale(LD2)
@@ -330,22 +330,22 @@ LD3n
 LD1
 LD2
 
-cat("###  restaureRealData ###\n")
-cleanProg(.longData3d.restaureRealData)
-restaureRealData(LD1)
-restaureRealData(LD1n)
-restaureRealData(LD2)
-restaureRealData(LD2n)
-restaureRealData(LD3)
-restaureRealData(LD3n)
-restaureRealData(LD4)
-restaureRealData(LD4n)
-restaureRealData(LD5)
-restaureRealData(LD5n)
-restaureRealData(LD6)
-restaureRealData(LD6n)
-restaureRealData(LD7)
-restaureRealData(LD7n)
+cat("###  restoreRealData ###\n")
+cleanProg(.longData3d.restoreRealData)
+restoreRealData(LD1)
+restoreRealData(LD1n)
+restoreRealData(LD2)
+restoreRealData(LD2n)
+restoreRealData(LD3)
+restoreRealData(LD3n)
+restoreRealData(LD4)
+restoreRealData(LD4n)
+restoreRealData(LD5)
+restoreRealData(LD5n)
+restoreRealData(LD6)
+restoreRealData(LD6n)
+restoreRealData(LD7)
+restoreRealData(LD7n)
 
 
 
